<?php
	$table_system_info = array(
		0x00000001		=> "チューナー機能",
		0x00000002		=> "VoIP Rx機能",
		0x00000004		=> "VoIP Tx機能",
		0x00000008		=> "DLスケジューラ",
		0x00000010		=> "TSファイル再生機能",
		0x00000020		=> "TSファイル録画機能",
		0x00000100		=> "入力切替機能",
		0x00000200		=> "マルチプレクサ機能 Ver.1 (ヨーズマー用)",
		0x00000400		=> "PSI/SI設定機能",
		0x00000800		=> "簡易DVB機能",
		0x00001000		=> "ASI OUT 機能",
		0x00002000		=> "ASI IN 機能",
		0x00010000		=> "TS over IP Rx 機能 Ver.2 (DBS7000用)",
		0x00020000		=> "TS over IP Tx 機能 Ver.2 (DBS7000用)",
		0x00040000		=> "TS over IP Rx 機能 Ver.3 (HNUX000用) 3ポート機器のポート1",
		0x00080000		=> "TS over IP Rx 機能 Ver.3 (HNUX000用) 3ポート機器のポート2",
		0x00100000		=> "TS over IP Rx 機能 Ver.3 (HNUX000用) 3ポート機器のポート3",
		0x00200000		=> "TS over IP Tx 機能 Ver.3 (HNUX000用) 3ポート機器のポート1",
		0x00400000		=> "TS over IP Tx 機能 Ver.3 (HNUX000用) 3ポート機器のポート2",
		0x00800000		=> "TS over IP Tx 機能 Ver.3 (HNUX000用) 3ポート機器のポート3",
		0x01000000		=> "マルチプレクサ機能 Ver.2 (DBS7000用)",
		0x02000000		=> "マルチプレクサ機能 Ver.3 (HNUX000用)",
		0x04000000		=> "TOTサーバ機能",
	);
	
	$table_option_info = array(
		0x00000001		=> "BMLファイル転送機能",
		0x00000002		=> "EPGファイル転送機能",
		0x00000004		=> "EMMファイル転送機能",
		0x00000008		=> "SNMP機能",
//		0x00010000		=> "ASI出力機能",
//		0x00020000		=> "ASI入力機能",
//		0x00000010		=> "冗長化機能（空き）",
		0x00000020		=> "ReMUX機能",
		0x00000040		=> "EIT収集機能(Tuner有時のみ)",
//		0x01000000		=> "EEPROM保存機能",
	);

	$table_customer_info = array(
		OEM_YOOZMA		=> "ヨーズマー",
		OEM_DKK			=> "電気興業",
		OEM_JPNANT		=> "日本アンテナ",
	);

/**
 * SYSCONFIG更新
 * @param type $system_conf		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_system_config($system_conf, $new_config)
{
	// 入力チェック
	if( !check_number_hex($new_config['unitid'], 4) ){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ユニットIDの設定が不正です。');
	}
	if( 31 < strlen($new_config['unitname']) ){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ユニット名称の設定が長すぎます。');
	}
	
	$new_config['unitid'] = str_pad( $new_config['unitid'], 8, '0', STR_PAD_LEFT);
	
	$tmp = 0;
	if(isset($new_config['systeminfo'])){
		foreach( $new_config['systeminfo'] as $val ){
			$tmp += intval($val, 10);
		}
	}
	$new_config['systeminfo'] = sprintf("%08X", $tmp);
	
	// 重複チェック
	$check_int = intval( $tmp );
	if( ( ( 0x00050000 & $check_int ) == 0x00050000 ) ||
		( ( 0x00090000 & $check_int ) == 0x00090000 ) ||
		( ( 0x00110000 & $check_int ) == 0x00110000 ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '「VoIP Rx(冗長化) 1ポート機器のみ」と「VoIP Rx(冗長化) 3ポート機器のポートX」は同時に選択することができません。');
	}
	if( ( ( 0x00220000 & $check_int ) == 0x00220000 ) ||
		( ( 0x00420000 & $check_int ) == 0x00420000 ) ||
		( ( 0x00820000 & $check_int ) == 0x00820000 ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '「VoIP Tx(冗長化) 1ポート機器のみ」と「VoIP Tx(冗長化) 3ポート機器のポートX」は同時に選択することができません。');
	}
	
	if( ( ( 0x00030000 & $check_int ) == 0x00030000 ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '「VoIP Rx(冗長化) 1ポート機器のみ」と「VoIP Tx(冗長化) 1ポート機器のみ」は同時に選択することができません。');
	}
	
	if( ( ( 0x00240000 & $check_int ) == 0x00240000 ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '「VoIP Rx(冗長化) 3ポート機器のポート1」と「VoIP Tx(冗長化) 3ポート機器のポート1」は同時に選択することができません。');
	}
	if( ( ( 0x00480000 & $check_int ) == 0x00480000 ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '「VoIP Rx(冗長化) 3ポート機器のポート2」と「VoIP Tx(冗長化) 3ポート機器のポート2」は同時に選択することができません。');
	}
	if( ( ( 0x00900000 & $check_int ) == 0x00900000 ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '「VoIP Rx(冗長化) 3ポート機器のポート3」と「VoIP Tx(冗長化) 3ポート機器のポート3」は同時に選択することができません。');
	}
	
	$tmp = 0;
	if(isset($new_config['optioninfo'])){
		foreach( $new_config['optioninfo'] as $val ){
			$tmp += intval($val, 10);
		}
	}
	$new_config['optioninfo'] = sprintf("%08X", $tmp);
	$new_config['custuminfo'] = sprintf("%08X", $new_config['custuminfo']);
	
	// 設定値を登録
	$system_conf['DBSSystem']['UnitID']			 = $new_config['unitid'];
	$system_conf['DBSSystem']['UnitName']		 = $new_config['unitname'];
	$system_conf['DBSSystem']['SystemInfo']		 = $new_config['systeminfo'];
	$system_conf['DBSSystem']['OptionInfo']		 = $new_config['optioninfo'];
	$system_conf['DBSSystem']['CustumInfo']		 = $new_config['custuminfo'];
	$system_conf['DBSSystem']['Language']		 = $new_config['language'];
	
	// ファイルに書き込み
	$filename['Setup']	 = SYSTEM_CONF;
	$filename['Save']	 = SYSTEM_CONF_SD;
	$result =  save_ini_file_setup_save( $filename, $system_conf );
	if( $result['RESULT'] == true ){
		$result['MESSAGE'] = '設定が正常に更新されました。変更した設定を有効にするためには機器のスイッチOFF/ONを実行してください。';
	}
	return $result;
}
?>
