<?php
define('PID_MAX',		0x1FFF);

define('INPUT_PID_START', 0);
define('INPUT_PID_END', 19);
define('INPUT_PID_INC', 1);

define('GET_PID_TABLE_COL_NUM',		8);

define('MUX_IN_GRAPH_WIDTH',		400 * 0.34);	// 400pxの34%幅で表示
define('MUX_IN_BITRATE_MAX_YZM',	35);			// LSB：1Mbps (Yoozmaは固定）
define('MUX_IN_BITRATE_ERR',		32.5);			// LSB：1Mbps	この値以上のビットレートはエラーとする

define('MUX_IN_BITRATE_MIN',		1);				// LSB：1Mbps
define('MUX_IN_BITRATE_MAX',		200);			// LSB：1Mbps
define('MUX_IN_BITRATE_ERR_RATE',	0.928);			// LSB：1Mbps	この値 * 最大ビットレート を超過した場合、ビットレートはエラーとする
define('MUX_IN_BITRATE_LSB',		1000000.0 );	// ビットレートLSB
define('MUX_IN_BITRATE_STEP',		1);				// LSB：1Mbps	グラフの最大値を変更するRangeのステップ
define('MUX_IN_BITRATE_UNIT',		35);			// LSB：1Mbps	グラフの初期レンジを設定する場合の単位

define('COOKIE_BITRATE_MAX',		'bitrate_max' );

define('MUX_IN_OUT_GRAPH_WIDTH',	400 * 0.5);		// 400pxの50%幅で表示

define('MUX_IN_OUT_PID_NUM',		32);

define('ENABLE_RATE_WARNING',		0.95);			// 有効データレートのワーニング表示レート（データレートリミットに対するレート）
define('ENABLE_RATE_ERROR',			0.99);			// 有効データレートのエラー表示レート（データレートリミットに対するレート）

require_once( get_common_lang_file() );
//require_once( get_lang_file(__FILE__) );	// Languageファイル読み込み

/**
 * 入力PIDの更新
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_input_pid( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	if(!isset($new_config['ts']) ||
		(1 != $new_config['ts'] &&
		 2 != $new_config['ts'])){
		return array('RESULT'  => false,
					 'MESSAGE' => '内部エラーが発生しました。TS番号異常です。');
	}
	
	if( is_fact() ){		// STとCTの16進数チェック
		for( $pid_no = INPUT_PID_START ; $pid_no <= INPUT_PID_END ; $pid_no += INPUT_PID_INC ){
			if( !check_number_hex($new_config['input_pid_stream_type'][$pid_no], 2) ){
				return array('RESULT'  => false,
							 'MESSAGE' => 'STREAM TYPEには2桁の16進数を設定してください。');
			}
			if( !check_number_hex($new_config['input_pid_component_tag'][$pid_no], 2) ){
				return array('RESULT'  => false,
							 'MESSAGE' => 'COMPONENT TAGには2桁の16進数を設定してください。');
			}
		}
	}
	
	$ts_no =  $new_config['ts'];
	for( $pid_no = INPUT_PID_START ; $pid_no <= INPUT_PID_END ; $pid_no += INPUT_PID_INC ){
		// 入力文字チェック
		if( !(preg_match("/^[0-9a-fA-F]+$/", $new_config['input_pid_input'][$pid_no]) ) ||
			!(preg_match("/^[0-9a-fA-F]+$/", $new_config['input_pid_changed'][$pid_no]))){
			return array('RESULT'  => false,
						 'MESSAGE' => '#'. $pid_no . 'のPIDが16進数で設定されていません。PIDは16進数で設定してください。');
		}

		// 最大値チェック
		if( ( PID_MAX < hexdec( $new_config['input_pid_input'][$pid_no] ) ) ||
			( PID_MAX < hexdec( $new_config['input_pid_changed'][$pid_no] ) ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => '入力されたPIDが最大値である'.sprintf("0x%04X", PID_MAX).'を超えています。');
		}

		// 設定値を保存
		if( isset( $new_config['input_pid_enable'][$pid_no] ) ){
			$old_config['FILTER' . ($ts_no - 1)]['SETTING'.$pid_no]	= 1;
		}else{
			$old_config['FILTER' . ($ts_no - 1)]['SETTING'.$pid_no]	= 0;
		}
		
		$old_config['FILTER' . ($ts_no - 1)]['INPUT'.$pid_no]	= '0x'.$new_config['input_pid_input'][$pid_no];
		$old_config['FILTER' . ($ts_no - 1)]['CHANGED'.$pid_no] = '0x'.$new_config['input_pid_changed'][$pid_no];
		
		if( is_fact() ){
			$old_config['FILTER' . ($ts_no - 1)]['STREAM_TYPE'.$pid_no] = '0x'.$new_config['input_pid_stream_type'][$pid_no];
			$old_config['FILTER' . ($ts_no - 1)]['COMPONENT_TAG'.$pid_no] = '0x'.$new_config['input_pid_component_tag'][$pid_no];
		}
	}
	$old_config['FILTER' . ($ts_no - 1)]['STATUS'] = $new_config['status'];

	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

function calc_bitrate($packet_size, $packet_num){
	// * 8 は Byte -> Bit 変換
	return round($packet_size * $packet_num * 8 / 1000 /1000, 3);
}

/**
 * 入力PIDの更新
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_mux_in_set( &$old_config, $new_config, $filename ){
	global $clng;
	// 入力情報のチェック
	$old_config['MUX']['MODE'] = $new_config['mode'];

	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => $clng['ER_FILE_WRITE_OK']);
	}
}
function save_conf_mux2_in_set(&$old_config, $new_config, $filename ){
	
	if( isset($new_config['TYPE']) ){
		// 0=ISDBT, 1=ケーブル
		$old_config['MUX']['TYPE'] = $new_config['TYPE'];
	}
	if( isset($new_config['mode']) ){
		// 0=13セグ, 1=1+12セグ, 2=1+12(NULL), 3=1セグ
		$old_config['MUX']['MODE'] = $new_config['mode'];
	}
	if( isset($new_config['freq']) ){
		// 中心周波数 (default=623MHz)
		$old_config['MUX']['FREQ'] = $new_config['freq'];
	}
	if( isset($new_config['rate']) ){
		$old_config['MUX']['RATE'] = ($new_config['rate']*1000*1000);
	}
	if( isset($new_config['debug']) ){
		$old_config['MUX']['DEBUG'] = $new_config['debug'];
	}
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => $clng['ER_FILE_WRITE_OK']);
	}
}
?>
