<?php
define('PID_MAX',		0x1FFF);

define('INPUT_PID_START', 0);
define('INPUT_PID_END', 60);
define('INPUT_PID_INC', 1);

define('GET_PID_TABLE_COL_NUM',		8);

define('MUX_INPUTSRC_GRAPH_WIDTH',		400 * 0.34);	// 400pxの34%幅で表示
define('MUX_INPUTSRC_BITRATE_MAX',		35);			// LSB：1Mbps
define('MUX_INPUTSRC_BITRATE_ERR',		32.5);			// LSB：1Mbps	この値以上のビットレートはエラーとする
define('MAX_ELEMENTARY_STREAM', 16);
define('NON_PID','FFFFFFFF');
/**
 * 入力PIDの更新
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_input_pid( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	if( !isset($new_config['ts']) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '内部エラーが発生しました。TS番号異常です。');
	}
	
	for( $pid_no = INPUT_PID_START ; $pid_no < INPUT_PID_END ; $pid_no += INPUT_PID_INC ){
		if( isset( $new_config['input_pid_stream_type'][$pid_no] ) ){
			if( !check_number_hex($new_config['input_pid_stream_type'][$pid_no], 2) ){
				return array('RESULT'  => false,
							 'MESSAGE' => 'STREAM TYPEには2桁の16進数を設定してください。');
			}
			if( !check_number_hex($new_config['input_pid_component_tag'][$pid_no], 2) ){
				return array('RESULT'  => false,
							 'MESSAGE' => 'COMPONENT TAGには2桁の16進数を設定してください。');
			}
		}
	}
	
	$ts_no =  $new_config['ts'];
	for( $pid_no = INPUT_PID_START ; $pid_no < INPUT_PID_END ; $pid_no += INPUT_PID_INC ){
		if( isset( $new_config['input_pid_input'][$pid_no] ) ){
			// 入力文字チェック
			if( !(preg_match("/^[0-9a-fA-F]+$/", $new_config['input_pid_input'][$pid_no]) ) ||
				!(preg_match("/^[0-9a-fA-F]+$/", $new_config['input_pid_changed'][$pid_no]))){
				return array('RESULT'  => false,
							 'MESSAGE' => '#'. $pid_no . 'のPIDが16進数で設定されていません。PIDは16進数で設定してください。');
			}

			// 最大値チェック
			if( ( PID_MAX < hexdec( $new_config['input_pid_input'][$pid_no] ) ) ||
				( PID_MAX < hexdec( $new_config['input_pid_changed'][$pid_no] ) ) ){
				return array('RESULT'  => false,
							 'MESSAGE' => '入力されたPIDが最大値である'.sprintf("0x%04X", PID_MAX).'を超えています。');
			}

			// 設定値を保存
			if( isset( $new_config['input_pid_enable'][$pid_no] ) && $new_config['input_pid_enable'][$pid_no] ){
				$old_config['FILTER' . ($ts_no - 1)]['SETTING'.$pid_no]	= 1;
			}else{
				$old_config['FILTER' . ($ts_no - 1)]['SETTING'.$pid_no]	= 0;
			}
		
			$old_config['FILTER' . ($ts_no - 1)]['INPUT'.$pid_no] = '0x'.$new_config['input_pid_input'][$pid_no];
			$old_config['FILTER' . ($ts_no - 1)]['CHANGED'.$pid_no] = '0x'.$new_config['input_pid_changed'][$pid_no];
			
			$old_config['FILTER' . ($ts_no - 1)]['STREAM_TYPE'.$pid_no] = '0x'.$new_config['input_pid_stream_type'][$pid_no];
			$old_config['FILTER' . ($ts_no - 1)]['COMPONENT_TAG'.$pid_no] = '0x'.$new_config['input_pid_component_tag'][$pid_no];
		}
	}
	$old_config['FILTER' . ($ts_no - 1)]['STATUS'] = $new_config['status'];
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

function calc_bitrate($packet_size, $packet_num){
	// * 8 は Byte -> Bit 変換
	return round($packet_size * $packet_num * 8 / 1000 / 1000, 3);
}

?>
