<?php
if( $_SERVER['DOCUMENT_ROOT'] == 'C:/xampp/htdocs' ){
	define( 'OFDM_SETUP_FILE',		'C:\xampp\htdocs\xampp\tmp\DAC_OFDM_SPI.csv' );
}else{
	define( 'OFDM_SETUP_FILE',		'/usr/hirotech/sys/DAC_OFDM_SPI.csv' );
}

define('PSI_TV_NUM_START',			'1');
define('PSI_TV_NUM_END',			'4');
define('PSI_TV_NUM_INC',			'1');

define('PSI_REMOCON_KEY_START',		'1');
define('PSI_REMOCON_KEY_END',		'12');
define('PSI_REMOCON_KEY_INC',		'1');

define('PSI_PROGRAM_NUM_START',		1);
define('PSI_PROGRAM_NUM_END',		8);
define('PSI_PROGRAM_NUM_INC',		1);

define('PSI_BUSINESS_PERSON_MAX',	32);
define('PSI_PROGRAM_NAME_MAX',		32);

define ('OUTPUT_GAIN_START',		'80.0');
define ('OUTPUT_GAIN_END',			'110.0');
define ('OUTPUT_GAIN_END_ONESEG',	'105.0');			// 1セグメントの場合の最大値
define ('OUTPUT_GAIN_LSB',			'0.1');

define ('NETWORK_DELAY_MIN',		'1');
//define ('NETWORK_DELAY_MAX',		'999999');
define ('NETWORK_DELAY_MAX',		'1800000');

define ('NETWORK_TIME_LSB',			10000);

define ('OFDM_BOARD_VER1',			'Ver0100005F');		// ボードバージョン番号 Setup_OFDM_XX.iniのセクション名に使用
define ('OFDM_BOARD_VER2',			'Ver0100006F');		// ボードバージョン番号 Setup_OFDM_XX.iniのセクション名に使用
define ('OFDM_BOARD_VER3',			'Ver0100007F');		// ボードバージョン番号 Setup_OFDM_XX.iniのセクション名に使用

define ('OFDM_CH_OFFSET_MIN',		-32768);
define ('OFDM_CH_OFFSET_MAX',		32767);

$gain_max = array(
		0 => OUTPUT_GAIN_END / OUTPUT_GAIN_LSB,
		1 => OUTPUT_GAIN_END / OUTPUT_GAIN_LSB,
		2 => OUTPUT_GAIN_END / OUTPUT_GAIN_LSB,
		3 => OUTPUT_GAIN_END_ONESEG / OUTPUT_GAIN_LSB,
	);

/**
 * OFDMの基本情報設定
 * @param type $old_config
 * @param type $new_config
 * @param type $filename
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_ofdm_base( &$old_config, $new_config, $filename ) {
	global $gain_max;
	
	if( isset($new_config['network_delay']) ){
		$new_config['network_delay'] = $new_config['network_delay'] * 1000;
	}
	
	// 入力情報のチェック
	if( (isset($new_config['network_delay'])) &&
		(( $new_config['network_delay'] < NETWORK_DELAY_MIN ) || 
		 ( NETWORK_DELAY_MAX < $new_config['network_delay'] ) )){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ネットワークディレイ設定は' . sprintf( "%.3f" , NETWORK_DELAY_MIN / 1000 ) .'msから' . sprintf( "%.3f", NETWORK_DELAY_MAX /1000 ) . 'msの範囲で設定して下さい。');
	}
	
	// モードにより出力Gainの最大値が異なるので最大値を調整
	if( $gain_max[$new_config['ofdm_mode']] < $old_config['RF']['Gain'] ){
		$old_config['RF']['Gain'] = $gain_max[$new_config['ofdm_mode']];
	}

	// 入力情報反映
	$old_config['OFDM']['Enable']		= $new_config['enable'];
	if( isset($new_config['ofdm_mode']) ){
		$old_config['OFDM']['OFDM_Mode']	= $new_config['ofdm_mode'];
	}
	$old_config['OFDM']['Sel_Clock']	= $new_config['sel_clock'];
	
	if( isset($new_config['gps_lock'] ) ){
		$old_config['SFN']['GPS_Lock']		= $new_config['gps_lock'];
		$old_config['SFN']['TS_Select']		= $new_config['ts_select'];
		$old_config['SFN']['SFN_Mode']		= $new_config['sfn_mode'];
		$old_config['SFN']['Input_Rate']	= $new_config['input_rate'];
		$old_config['SFN']['GPS_Lock']		= $new_config['gps_lock'];
		
	}
	if( isset($new_config['network_delay'] ) ){
		$old_config['SFN']['Maximum_Delay']	= $new_config['network_delay'];
	}

	// ファイルへ保存 RAMとSDに保存する
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

/**
 * OFDMのRF情報設定
 * @param type $old_config
 * @param type $new_config
 * @param type $filename
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_ofdm_rf( &$old_config, $new_config, $filename ) {
	global $gain_max;
	// 入力情報のチェック
	
	if( !check_number_decimal( $new_config['output_gain'], 1 ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '出力ゲインは小数点第一位までの数値を入力してください。');
	}
	$max = ( $old_config['OFDM']['OFDM_Mode'] != 3 ) ? OUTPUT_GAIN_END : OUTPUT_GAIN_END_ONESEG;
	
	$max = $gain_max[ $old_config['OFDM']['OFDM_Mode'] ] * OUTPUT_GAIN_LSB;
	
	
	if( ( $new_config['output_gain'] < OUTPUT_GAIN_START ) || 
		( $max < $new_config['output_gain'] ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '出力ゲインは ' . OUTPUT_GAIN_START . ' ～ ' . sprintf("%.1f", $max) . ' dBμV の範囲で設定可能です。 ' );
	}
	
	// 入力情報反映
	$old_config['RF']['RF']				= $new_config['output_ch'];
	$old_config['RF']['Gain']			= $new_config['output_gain'] / OUTPUT_GAIN_LSB;
	if( isset($new_config['cw_mode'])){
		$old_config['RF']['CW_Mode']	= $new_config['cw_mode'];
	}

	// ファイルへ保存 RAMとSDに保存する
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

/**
 * OFDMのRF情報設定(工場出荷情報)
 * @param type $old_config
 * @param type $new_config
 * @param type $filename
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_ofdm_rf_fact( &$old_config, $new_config, $filename ) {
	// 入力情報のチェック
	if( !check_number_enable_minus($new_config['ch_offset']) || ( ( $new_config['ch_offset'] < OFDM_CH_OFFSET_MIN ) || ( OFDM_CH_OFFSET_MAX < $new_config['ch_offset'] ) ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => 'RFチャンネル中心周波数用オフセット値 (全チャンネル共通)は ' . OFDM_CH_OFFSET_MIN . ' から ' . OFDM_CH_OFFSET_MAX . ' の範囲の数値を設定してください。');
	}
	if(!check_number($new_config['rf_ch_gain1'])){
		return array('RESULT'  => false,
					 'MESSAGE' => 'RFチャンネルゲイン1は数値を設定してください。');
	}
	if(!check_number($new_config['rf_ch_gain2'])){
		return array('RESULT'  => false,
					 'MESSAGE' => 'RFチャンネルゲイン2は数値を設定してください。');
	}
	if(isset( $new_config['og_max_95db'] ) && !check_number($new_config['og_max_95db'])){
		return array('RESULT'  => false,
					 'MESSAGE' => '出力ゲイン 95dbは数値を設定してください。');
	}
	if(isset( $new_config['og_max_80db'] ) && !check_number($new_config['og_max_80db'])){
		return array('RESULT'  => false,
					 'MESSAGE' => '出力ゲイン 80dbは数値を設定してください。');
	}
	if(!check_number($new_config['og_max_110db'])){
		return array('RESULT'  => false,
					 'MESSAGE' => '出力ゲイン 110dbは数値を設定してください。');
	}
	if(!check_number($new_config['cw_offset_db'])){
		return array('RESULT'  => false,
					 'MESSAGE' => 'CWモードGain Offset (db)は数値を設定してください。');
	}
	if(!check_number($new_config['vcxo_adjust'])){
		return array('RESULT'  => false,
					 'MESSAGE' => 'VCXO調整値は数値を設定してください。');
	}
	
	// 入力情報反映
	$ofdm_version = OFDM_BOARD_VER1;
	if( isset( $old_config[OFDM_BOARD_VER2] ) ){
		$ofdm_version = OFDM_BOARD_VER2;
	}else if( isset( $old_config[OFDM_BOARD_VER3] ) ){
		$ofdm_version = OFDM_BOARD_VER3;
	}
	$old_config[$ofdm_version]['CH_Offset']		= $new_config['ch_offset'];
	$old_config[$ofdm_version]['RF_CH_Gain1']	= $new_config['rf_ch_gain1'];
	$old_config[$ofdm_version]['RF_CH_Gain2']	= $new_config['rf_ch_gain2'];
	if( isset( $new_config['og_max_95db'] ) ){
		$old_config[$ofdm_version]['Level_Max_95']	= $new_config['og_max_95db'];
		$old_config[$ofdm_version]['Level_Max_110']	= $new_config['og_max_110db'];
	}
	if( isset( $new_config['og_max_80db'] ) ){
		$old_config[$ofdm_version]['Gain_80dvuv']	= $new_config['og_max_80db'];
		$old_config[$ofdm_version]['Gain_110dvuv']	= $new_config['og_max_110db'];
	}
	
	$old_config[$ofdm_version]['CW_Offset']		= $new_config['cw_offset_db'];
	$old_config[$ofdm_version]['VCXO_Adj']		= $new_config['vcxo_adjust'];
	$old_config[$ofdm_version]['VCXO_Auto']		= $new_config['vcxo_auto'];
	$old_config[$ofdm_version]['Debug_Mode']	= $new_config['debug_mode'];
	$old_config[$ofdm_version]['Freq_65Mhz']	= $new_config['freq_65mhz'];
	
	// ファイルへ保存 RAMとSDに保存する
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

/**
 * PSIの設定情報保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_psi( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	// 事業者名長チェック
	if( PSI_BUSINESS_PERSON_MAX < strlen( $new_config['business_person'] ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '事業者名の入力文字数が多すぎます。最大'.PSI_BUSINESS_PERSON_MAX.'文字(半角)まで登録可能です。');
	}
	
	// プログラム名長チェック
	for( $tv_no = PSI_TV_NUM_START ; $tv_no <= PSI_TV_NUM_END ; $tv_no += PSI_TV_NUM_INC ){
		if( PSI_PROGRAM_NAME_MAX < strlen( $new_config['tv'.$tv_no.'_prg_name'] )){
			return array('RESULT'  => false,
						 'MESSAGE' => 'プログラム名の入力文字数が多すぎます。最大'.PSI_PROGRAM_NAME_MAX.'文字(半角)まで登録可能です。');
		}
	}
	
	$old_config['OFDM_PSI']['REMOCON_KEY']		= $new_config['remocon_key'];
	$old_config['OFDM_PSI']['BUSINESS_PERSON']	= $new_config['business_person'];
	$old_config['OFDM_PSI']['AREA_CODE']		= $new_config['area_code'];
	$old_config['OFDM_PSI']['AREA_BUS_PERSON']	= $new_config['area_bus_person'];
	$old_config['OFDM_PSI']['PREFECTURES_FLAG']	= $new_config['prefectures_flag'];
	
	for( $tv_no = PSI_TV_NUM_START ; $tv_no <= PSI_TV_NUM_END ; $tv_no += PSI_TV_NUM_INC ){
		$old_config['TV'.$tv_no]['STATUS']   = $new_config['tv'.$tv_no.'_prg_status'];
		$old_config['TV'.$tv_no]['NUMBER']   = $new_config['tv'.$tv_no.'_prg_number'];
		$old_config['TV'.$tv_no]['NAME']     = $new_config['tv'.$tv_no.'_prg_name'];
		$old_config['TV'.$tv_no]['SCRAMBLE'] = $new_config['tv'.$tv_no.'_prg_scramble'];
		$old_config['TV'.$tv_no]['COPY']     = $new_config['tv'.$tv_no.'_prg_copy'];
	}
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}
?>
