<?php

define('PID_MAX',		0x1FFF);

define('IP_PACKET_BUFFER_SIZE_MIN',    32);
define('IP_PACKET_BUFFER_SIZE_MAX',    1024);

//define('SAVING_TIME_MIN',				100);
define('SAVING_TIME_MIN',				10);
define('SAVING_TIME_MAX',				1000);

define('SSRC_MIN',						0x00000000);
define('SSRC_MAX',						0xFFFFFFFF);

define('TS_IP_BITRATE_MIN',				0);
define('TS_IP_BITRATE_MAX',				100000000);
define('TS_IP_BITRATE_MAX_G',			1000000000);

define('TS_BITRATE_MIN',				0);
define('TS_BITRATE_MAX',				100000000);

$firewall_label = array( 'UDP Port', 'UDP Port+SSRC', 'IP+UDP Port', 'IP+UDP Port+SSRC' );

define('FEC_DXL_MAX',		100);

// 
/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_voip( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	if( false == check_ip( $new_config['setting_rx_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '受信IPアドレスの入力が不正です。');
	}
	if( false == check_netmask( $new_config['setting_net_mask'] ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ネットマスクの入力が不正です。');
	}
	if( false == check_ip( $new_config['setting_gw_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ゲートウェイIPアドレスの入力が不正です。');
	}
	
	$old_config['RVOIPRx']['Status']	 = $new_config['status'];
	$old_config['RVOIPRx']['RxIP']       = $new_config['setting_rx_ip'];
	$old_config['RVOIPRx']['Mask']		 = $new_config['setting_net_mask'];
	$old_config['RVOIPRx']['GwIP']       = $new_config['setting_gw_ip'];
	$old_config['RVOIPRx']['Firewall']   = $new_config['firewall'];
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_stream( &$old_config, $new_config, $filename ){
	
	// 全ストリームのチェック
	for( $i = 0 ; $i < RVOIP_STREAM_NUM ; $i++ ){
		// 遅延時間
		if(!(preg_match("/^[0-9]+$/", $new_config['saving_time'.$i]))){
			return array('RESULT'  => false,
						 'MESSAGE' => 'ストリーム'.$i.'の遅延時間には数値を設定してください。');
		}
		if( ( $new_config['saving_time'.$i] < SAVING_TIME_MIN ) ||
			( SAVING_TIME_MAX < $new_config['saving_time'.$i] )	) {
			return array('RESULT'  => false,
						 'MESSAGE' => 'ストリーム'.$i.'の遅延時間には '. SAVING_TIME_MIN .' ～ '. SAVING_TIME_MAX .' の範囲で設定してください。');
		}
		
		// 送信元IP
		if( false == check_ip( $new_config['rx_your_ip_addr'.$i], true ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => 'ストリーム'.$i.'の送信元IPアドレスの入力が不正です。');
		}
		
		// SSRC
		if(!(preg_match("/^[0-9]+$/", $new_config['rx_ssrc'.$i]))){
			return array('RESULT'  => false,
						 'MESSAGE' => 'ストリーム'.$i.'のSSRCには数値を設定してください。');
		}
		if( ( $new_config['rx_ssrc'.$i] < SSRC_MIN ) ||
			( SSRC_MAX < $new_config['rx_ssrc'.$i] )	) {
			return array('RESULT'  => false,
						 'MESSAGE' => 'ストリーム'.$i.'のSSRCには '. SSRC_MIN .' ～ '. SSRC_MAX .' の範囲で設定してください。');
		}
		
		$old_config['STREAM'.$i]['TsPort']			 = $new_config['ts_out_port'.$i];
		$old_config['STREAM'.$i]['SavingTime']		 = $new_config['saving_time'.$i];
		$old_config['STREAM'.$i]['UdpPort']			 = $new_config['rx_udp_port'.$i];
		$old_config['STREAM'.$i]['RxYourIPAddr']	 = $new_config['rx_your_ip_addr'.$i];
		$old_config['STREAM'.$i]['Ssrc']			 = $new_config['rx_ssrc'.$i];
		
		if( is_debug() ){
			// CCError計測用PID
			if( !check_number_hex( $new_config['rx_pid'.$i], 4 ) ){
				return array('RESULT'  => false,
							 'MESSAGE' => 'CCError計測Video PIDは16進数で設定してください。');
			}
			
			if( PID_MAX < hexdec( $new_config['rx_pid'.$i] ) ){
				return array('RESULT'  => false,
							 'MESSAGE' => '入力されたCCError計測用Video PIDが最大値である'.sprintf("0x%04X", PID_MAX).'を超えています。');
			}
			
			$old_config['STREAM'.$i]['MesureVideoPid']	 = $new_config['rx_pid'.$i];
		}
	}
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}


/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @param type $no				設定するストリーム番号（0始まりで指定）
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_stream_no( &$old_config, $new_config, $filename, $no ){
	// 遅延時間
	if(!(preg_match("/^[0-9]+$/", $new_config['saving_time'.$no]))){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ストリーム'.$no.'の遅延時間には数値を設定してください。');
	}
	if( ( $new_config['saving_time'.$no] < SAVING_TIME_MIN ) ||
		( SAVING_TIME_MAX < $new_config['saving_time'.$no] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => 'ストリーム'.$no.'の遅延時間には '. SAVING_TIME_MIN .' ～ '. SAVING_TIME_MAX .' の範囲で設定してください。');
	}
	
	// 送信元IP
	if( false == check_ip( $new_config['rx_your_ip_addr'.$no], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ストリーム'.$no.'の送信元IPアドレスの入力が不正です。');
	}
	
	// SSRC
	if(!(preg_match("/^[0-9]+$/", $new_config['rx_ssrc'.$no]))){
		return array('RESULT'  => false,
					 'MESSAGE' => 'ストリーム'.$no.'のSSRCには数値を設定してください。');
	}
	if( ( $new_config['rx_ssrc'.$no] < SSRC_MIN ) ||
		( SSRC_MAX < $new_config['rx_ssrc'.$no] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => 'ストリーム'.$no.'のSSRCには '. SSRC_MIN .' ～ '. SSRC_MAX .' の範囲で設定してください。');
	}
	
//	$old_config['STREAM'.$no]['TsPort']			 = $new_config['ts_out_port'.$no];
	$old_config['STREAM'.$no]['SavingTime']		 = $new_config['saving_time'.$no];
	$old_config['STREAM'.$no]['UdpPort']		 = $new_config['rx_udp_port'.$no];
	$old_config['STREAM'.$no]['RxYourIPAddr']	 = $new_config['rx_your_ip_addr'.$no];
	$old_config['STREAM'.$no]['Ssrc']			 = $new_config['rx_ssrc'.$no];
	
	if( is_debug() ){
		// CCError計測用PID
		if( !check_number_hex( $new_config['rx_pid'.$no], 4 ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => 'CCError計測Video PIDは16進数で設定してください。');
		}
		
		if( PID_MAX < hexdec( $new_config['rx_pid'.$no] ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => '入力されたCCError計測用Video PIDが最大値である'.sprintf("0x%04X", PID_MAX).'を超えています。');
		}
		
		$old_config['STREAM'.$no]['MesureVideoPid']	 = $new_config['rx_pid'.$no];
	}
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

/**
 * VoIPの設定情報の保存 冗長化対応のストリーム情報
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_stream_simple( &$old_config, $new_config, $filename ){
	// 遅延時間
	if(!(preg_match("/^[0-9]+$/", $new_config['saving_time0']))){
		return array('RESULT'  => false,
					 'MESSAGE' => '遅延時間には数値を設定してください。');
	}
	if( ( $new_config['saving_time0'] < SAVING_TIME_MIN ) ||
		( SAVING_TIME_MAX < $new_config['saving_time0'] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => '遅延時間には '. SAVING_TIME_MIN .' ～ '. SAVING_TIME_MAX .' の範囲で設定してください。');
	}
	
	// 送信元IP
	if( false == check_ip( $new_config['rx_your_ip_addr0'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '送信元IPアドレスの入力が不正です。');
	}
	
	// SSRC
	if(!(preg_match("/^[0-9]+$/", $new_config['rx_ssrc0']))){
		return array('RESULT'  => false,
					 'SSRCには数値を設定してください。');
	}
	if( ( $new_config['rx_ssrc0'] < SSRC_MIN ) ||
		( SSRC_MAX < $new_config['rx_ssrc0'] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => 'SSRCには '. SSRC_MIN .' ～ '. SSRC_MAX .' の範囲で設定してください。');
	}
	
	$old_config['STREAM0']['TsPort']		 = 0;	// 0固定
	$old_config['STREAM0']['SavingTime']	 = $new_config['saving_time0'];
	$old_config['STREAM0']['UdpPort']		 = $new_config['rx_udp_port0'];
	$old_config['STREAM0']['RxYourIPAddr']	 = $new_config['rx_your_ip_addr0'];
	$old_config['STREAM0']['Ssrc']			 = $new_config['rx_ssrc0'];
	$old_config['STREAM0']['MesureVideoPid'] = 0;
	
	// 冗長化を使用する場合はTSポートを0にして設定
	if( '1' == $new_config['use_redundant'] ){
		// 送信元IP（冗長化）
		if( false == check_ip( $new_config['rx_your_ip_addr1'], true ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => '送信元IPアドレスの入力が不正です。');
		}
		
		$old_config['STREAM1']['TsPort']		 = 0;	// 0固定
		$old_config['STREAM1']['UdpPort']		 = $new_config['rx_udp_port1'];
		$old_config['STREAM1']['RxYourIPAddr']	 = $new_config['rx_your_ip_addr1'];
		$old_config['STREAM1']['SavingTime']	 = $new_config['saving_time0'];		// Stream0と同値
		$old_config['STREAM1']['Ssrc']			 = $new_config['rx_ssrc0'];			// Stream0と同値
		$old_config['STREAM1']['MesureVideoPid'] = 0;
	}else{
		$old_config['STREAM1']['TsPort']		 = 1;	// 0固定
	}
	
	$old_config['RVOIPRx']['UseRedundant'] = $new_config['use_redundant'];
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}

/**
 * VoIPの ASI 設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_asi_setting( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	
	$old_config['RVOIPRx']['AsiSelect0'] = $new_config['asi_select0'];
	$old_config['RVOIPRx']['AsiSelect1'] = $new_config['asi_select1'];
	$old_config['RVOIPRx']['AsiSelect2'] = $new_config['asi_select2'];
	$old_config['RVOIPRx']['AsiSelect3'] = $new_config['asi_select3'];
	
	$old_config['RVOIPRx']['AsiTxMode0'] = $new_config['asi_tx_mode0'];
	$old_config['RVOIPRx']['AsiTxMode1'] = $new_config['asi_tx_mode1'];
	$old_config['RVOIPRx']['AsiTxMode2'] = $new_config['asi_tx_mode2'];
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}


/**
 * カウンタのリセット処理
 * @param type $stream_no		リセットするストリーム番号
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function control_counter_reset( $stream_no ){
	system( "echo 'RVOIPRX_COUNTER_RESET\r\nNO=". $stream_no. "' > ".MAINCONTROL );
	
	return array('RESULT'  => true,
				 'MESSAGE' => 'カウンタのリセット処理を行いました。');
	
}


?>
