<?php

define('PID_MAX',		0x1FFF);

define('IP_PACKET_BUFFER_SIZE_MIN',    32);
define('IP_PACKET_BUFFER_SIZE_MAX',    1024);

define('SAVING_TIME_MIN',				100);
define('SAVING_TIME_MAX',				1000);

define('SSRC_MIN',						0x00000000);
define('SSRC_MAX',						0xFFFFFFFF);

if(check_tuner8toip()){
	define('TX_BITRATE_TIMES',				4);			// ビットレートの倍率（TXのみ使用）
}else{
	define('TX_BITRATE_TIMES',				1);			// ビットレートの倍率（TXのみ使用）
}

define('TS_IP_BITRATE_MIN',				0);
define('TS_IP_BITRATE_MAX',				100000000);
define('TS_IP_BITRATE_MAX_G',			1000000000);

define('TS_BITRATE_MIN',				0);
define('TS_BITRATE_MAX',				100000000);
define('TS_BITRATE_MAX_G',				1000000000);


$firewall_label = array( 'UDP Port', 'UDP Port+SSRC', 'IP+UDP Port', 'IP+UDP Port+SSRC' );

define('FEC_DXL_MAX',		100);

require_once( get_common_lang_file() );
require_once( get_lang_file( __FILE__ ) );

// 
/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_voiptx( &$old_config, $new_config, $filename ){
	global $lng;
	
	// 入力情報のチェック
	if( false == check_ip( $new_config['setting_tx_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_DST_IP']);
	}
	if( false == check_netmask( $new_config['setting_net_mask'] ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_NETMSK']);
	}
	if( false == check_ip( $new_config['setting_gw_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_GW']);
	}
	
	$old_config['RVOIPTx']['Status']	 = $new_config['status'];
	$old_config['RVOIPTx']['TxIP']       = $new_config['setting_tx_ip'];
	$old_config['RVOIPTx']['Mask']		 = $new_config['setting_net_mask'];
	$old_config['RVOIPTx']['GwIP']       = $new_config['setting_gw_ip'];
	$old_config['RVOIPTx']['Firewall']   = $new_config['firewall'];
	
        // 1チャンネル目の設定が他の全てのチャンネルの設定に反映される
        $old_config['STREAM0']['TsSendNo'] = 0;
        $old_config['STREAM0']['TsPIp'] = $new_config['ts_p_ip_0'];
        $old_config['STREAM0']['EnableRowFec'] = $new_config['setting_fec_d_status_0'];
        $old_config['STREAM0']['EnableColumnFec'] = $new_config['setting_fec_l_status_0'];
        $old_config['STREAM0']['RowFec'] = $new_config['setting_fec_d_0'];
        $old_config['STREAM0']['ColumnFec'] = $new_config['setting_fec_l_0'];
        for( $i = 1 ; $i < 10 ; $i++ ){
            $old_config['STREAM'.$i]['TsSendNo'] = 0;
            $old_config['STREAM'.$i]['TsPIp'] = 0;
            $old_config['STREAM'.$i]['EnableRowFec'] = 0;
            $old_config['STREAM'.$i]['EnableColumnFec'] = 0;
            $old_config['STREAM'.$i]['RowFec'] = 0;
            $old_config['STREAM'.$i]['ColumnFec'] = 0;
        }
        
	return save_ini_file_setup_save( $filename, $old_config );
}

/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_stream( &$old_config, $new_config, $filename ){
	global $lng;
	
	// 全ストリームのチェック
	for( $i = 0 ; $i < RVOIP_STREAM_NUM ; $i++ ){
		
		// 送信先IP
		if( false == check_ip( $new_config['rx_your_ip_addr'.$i], false ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => sprintf( $lng['ER_DST_IP_ST'], $i ));
		}
		
		// 送信先UDPポート
		if(!(preg_match("/^[0-9]+$/", $new_config['rx_udp_port'.$i]))){
			return array('RESULT'  => false,
						 'MESSAGE' => sprintf( $lng['ER_DST_UDP_ST_NUM'], $i ));
		}
		if( ( $new_config['rx_udp_port'.$i] < 1 ) ||
			( 65535 < $new_config['rx_udp_port'.$i] )	) {
			return array('RESULT'  => false,
						 'MESSAGE' => sprintf( $lng['ER_DST_UDP_ST_RNG'], $i ));
		}
		
		// SSRC
		if(!(preg_match("/^[0-9]+$/", $new_config['tx_ssrc'.$i]))){
			return array('RESULT'  => false,
						 'MESSAGE' => sprintf( $lng['ER_SSRC_NUM_ST'], $i ));
		}
		if( ( $new_config['tx_ssrc'.$i] < SSRC_MIN ) ||
			( SSRC_MAX < $new_config['tx_ssrc'.$i] )	) {
			return array('RESULT'  => false,
						 'MESSAGE' => sprintf( $lng['ER_SSRC_RNG_ST'], SSRC_MIN, SSRC_MAX, $i ));
		}
		
		// FEC ROW
		if( $new_config['setting_fec_d_status_'.$i] == 0 ){
			$new_config['setting_fec_d_'.$i] = 1;
		}
		if( $new_config['setting_fec_l_status_'.$i] == 0 ){
			$new_config['setting_fec_l_'.$i] = 1;
		}
		
		$old_config['STREAM'.$i]['EnableTs']		 = $new_config['enable_ts_'.$i];
		$old_config['STREAM'.$i]['EnableRowFec']	 = $new_config['setting_fec_d_status_'.$i];
		$old_config['STREAM'.$i]['EnableColumnFec']	 = $new_config['setting_fec_l_status_'.$i];
		$old_config['STREAM'.$i]['TsPIp']			 = $new_config['ts_p_ip_'.$i];
		$old_config['STREAM'.$i]['TsSendNo']		 = $new_config['ts_send_no_'.$i];
		$old_config['STREAM'.$i]['RowFec']			 = $new_config['setting_fec_d_'.$i];
		$old_config['STREAM'.$i]['ColumnFec']		 = $new_config['setting_fec_l_'.$i];
		$old_config['STREAM'.$i]['YourIpAddr']		 = $new_config['rx_your_ip_addr'.$i];
		$old_config['STREAM'.$i]['YourUdpPort']		 = $new_config['rx_udp_port'.$i];
		$old_config['STREAM'.$i]['Ssrc']			 = $new_config['tx_ssrc'.$i];
	}
	
	return save_ini_file_setup_save( $filename, $old_config );
}

/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @param type $no				設定するストリーム番号
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_stream_no( &$old_config, $new_config, $filename, $no ){
	global $lng;
	
	// 送信先IP
	if( false == check_ip( $new_config['rx_your_ip_addr'.$no], false ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => sprintf( $lng['ER_DST_IP_ST'], $no ));
	}
	
	// 送信先UDPポート
	if(!(preg_match("/^[0-9]+$/", $new_config['rx_udp_port'.$no]))){
		return array('RESULT'  => false,
					 'MESSAGE' => sprintf( $lng['ER_DST_UDP_ST_NUM'], $no ));
	}
	if( ( $new_config['rx_udp_port'.$no] < 1 ) ||
		( 65535 < $new_config['rx_udp_port'.$no] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => sprintf( $lng['ER_DST_UDP_ST_RNG'], $no ));
	}
	
	// SSRC
	if(!(preg_match("/^[0-9]+$/", $new_config['tx_ssrc'.$no]))){
		return array('RESULT'  => false,
					 'MESSAGE' => sprintf( $lng['ER_SSRC_NUM_ST'], $no ));
	}
	if( ( $new_config['tx_ssrc'.$no] < SSRC_MIN ) ||
		( SSRC_MAX < $new_config['tx_ssrc'.$no] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => sprintf( $lng['ER_SSRC_RNG_ST'], SSRC_MIN, SSRC_MAX, $no ));
	}
/* ここではFECの設定は行わない
	// FEC ROW
	if( $new_config['setting_fec_d_status_'.$no] == 0 ){
		$new_config['setting_fec_d_'.$no] = 1;
	}
	if( $new_config['setting_fec_l_status_'.$no] == 0 ){
		$new_config['setting_fec_l_'.$no] = 1;
	}
*/
	$old_config['STREAM'.$no]['EnableTs']		 = $new_config['enable_ts_'.$no];
/*
        $old_config['STREAM'.$no]['EnableRowFec']	 = $new_config['setting_fec_d_status_'.$no];
	$old_config['STREAM'.$no]['EnableColumnFec']	 = $new_config['setting_fec_l_status_'.$no];
	$old_config['STREAM'.$no]['TsPIp']			 = $new_config['ts_p_ip_'.$no];
	$old_config['STREAM'.$no]['RowFec']			 = $new_config['setting_fec_d_'.$no];
	$old_config['STREAM'.$no]['ColumnFec']		 = $new_config['setting_fec_l_'.$no];
*/
	$old_config['STREAM'.$no]['YourIpAddr']		 = $new_config['rx_your_ip_addr'.$no];
	$old_config['STREAM'.$no]['YourUdpPort']		 = $new_config['rx_udp_port'.$no];
	$old_config['STREAM'.$no]['Ssrc']			 = $new_config['tx_ssrc'.$no];

	return save_ini_file_setup_save( $filename, $old_config );
}



/**
 * VoIPの設定情報の保存 冗長化対応のストリーム情報
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_stream_simple( &$old_config, $new_config, $filename ){
	global $lng;
	
	$i = 0;
	// ストリームのチェック
	// 送信先IP
	if( false == check_ip( $new_config['rx_your_ip_addr'.$i], false ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_DST_IP']);
	}
	
	// UDPポート
	if(!(preg_match("/^[0-9]+$/", $new_config['rx_udp_port'.$i]))){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_DST_UDP_NUM']);
	}
	if( ( $new_config['rx_udp_port'.$i] < 1 ) ||
		( 65535 < $new_config['rx_udp_port'.$i] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_DST_UDP_RNG']);
	}
	
	// SSRC
	if(!(preg_match("/^[0-9]+$/", $new_config['tx_ssrc'.$i]))){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_SSRC_NUM']);
	}
	if( ( $new_config['tx_ssrc'.$i] < SSRC_MIN ) ||
		( SSRC_MAX < $new_config['tx_ssrc'.$i] )	) {
		return array('RESULT'  => false,
					 'MESSAGE' => sprintf( $lng['ER_SSRC_RNG'], SSRC_MIN, SSRC_MAX ));
	}
	
	// FEC ROW
	if( $new_config['setting_fec_d_status_'.$i] == 0 ){
		$new_config['setting_fec_d_'.$i] = 1;
	}
	if( $new_config['setting_fec_l_status_'.$i] == 0 ){
		$new_config['setting_fec_l_'.$i] = 1;
	}
	
	$old_config['STREAM'.$i]['EnableTs']		 = $new_config['enable_ts_'.$i];
	$old_config['STREAM'.$i]['EnableRowFec']	 = $new_config['setting_fec_d_status_'.$i];
	$old_config['STREAM'.$i]['EnableColumnFec']	 = $new_config['setting_fec_l_status_'.$i];
	$old_config['STREAM'.$i]['TsPIp']			 = $new_config['ts_p_ip_'.$i];
	$old_config['STREAM'.$i]['TsSendNo']		 = 0; // 0固定
	$old_config['STREAM'.$i]['RowFec']			 = $new_config['setting_fec_d_'.$i];
	$old_config['STREAM'.$i]['ColumnFec']		 = $new_config['setting_fec_l_'.$i];
	$old_config['STREAM'.$i]['YourIpAddr']		 = $new_config['rx_your_ip_addr'.$i];
	$old_config['STREAM'.$i]['YourUdpPort']		 = $new_config['rx_udp_port'.$i];
	$old_config['STREAM'.$i]['Ssrc']			 = $new_config['tx_ssrc'.$i];
	
	$i = 1;
	if( '1' == $new_config['use_redundant'] ){
		// ストリームのチェック
		// 送信先IP
		if( false == check_ip( $new_config['rx_your_ip_addr'.$i], false ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_DST_IP_SUB']);
		}

		// UDPポート
		if(!(preg_match("/^[0-9]+$/", $new_config['rx_udp_port'.$i]))){
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_DST_UDP_NUM_SUB']);
		}
		if( ( $new_config['rx_udp_port'.$i] < 1 ) ||
			( 65535 < $new_config['rx_udp_port'.$i] )	) {
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_DST_UDP_RNG_SUB']);
		}
		
		// IP+UDP
		if( ( $new_config['rx_your_ip_addr0'] == $new_config['rx_your_ip_addr1'] ) &&
			( $new_config['rx_udp_port0'] == $new_config['rx_udp_port1'] ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_DST_SAME']);
		}
		
		$old_config['STREAM'.$i]['EnableTs']		 = 0;
		$old_config['STREAM'.$i]['EnableRowFec']	 = $new_config['setting_fec_d_status_0'];
		$old_config['STREAM'.$i]['EnableColumnFec']	 = $new_config['setting_fec_l_status_0'];
		$old_config['STREAM'.$i]['TsPIp']			 = $new_config['ts_p_ip_0'];
		$old_config['STREAM'.$i]['TsSendNo']		 = $old_config['STREAM0']['TsSendNo'];
		$old_config['STREAM'.$i]['RowFec']			 = $new_config['setting_fec_d_0'];
		$old_config['STREAM'.$i]['ColumnFec']		 = $new_config['setting_fec_l_0'];
		$old_config['STREAM'.$i]['YourIpAddr']		 = $new_config['rx_your_ip_addr1'];
		$old_config['STREAM'.$i]['YourUdpPort']		 = $new_config['rx_udp_port1'];
		$old_config['STREAM'.$i]['Ssrc']			 = $new_config['tx_ssrc0'];
	}else{
		//$old_config['STREAM'.$i]['EnableTs']		 = 0;
		$old_config['STREAM'.$i]['TsSendNo']		 = 1;
	}
	$old_config['RVOIPTx']['UseRedundant'] = $new_config['use_redundant'];
	
	// 関係ないストリームは念のためにそれぞれのストリーム番号に設定する
	for( $i = 2 ; $i < RVOIP_STREAM_NUM ; $i++ ){
		$old_config['STREAM'.$i]['TsSendNo'] = $i;
	}
	
	return save_ini_file_setup_save( $filename, $old_config );
}

/**
 * VoIPの ASI 設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_asi_setting( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	
	$old_config['RVOIPTx']['AsiSelect0'] = $new_config['asi_select0'];
	$old_config['RVOIPTx']['AsiSelect1'] = $new_config['asi_select1'];
	$old_config['RVOIPTx']['AsiSelect2'] = $new_config['asi_select2'];
	$old_config['RVOIPTx']['AsiSelect3'] = $new_config['asi_select3'];
	
	$old_config['RVOIPTx']['AsiTxMode0'] = $new_config['asi_tx_mode0'];
	$old_config['RVOIPTx']['AsiTxMode1'] = $new_config['asi_tx_mode1'];
	$old_config['RVOIPTx']['AsiTxMode2'] = $new_config['asi_tx_mode2'];
	
	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => $clng['ER_FILE_WRITE_OK']);
	}
}
function check_address( $sts_conf_RVOIPTx ,$dst_ip_str){
	
	$src_ip_array = explode(".",$sts_conf_RVOIPTx["RVOIPTx"]["TxIP"]);
	$dst_ip_array = explode(".",$dst_ip_str);
	$mask_array = explode(".",$sts_conf_RVOIPTx["RVOIPTx"]["Mask"] );
	
	$src_ip = $src_ip_array[0] << 24;
	$src_ip |= ($src_ip_array[1] << 16);
	$src_ip |= ($src_ip_array[2] << 8);
	$src_ip |= $src_ip_array[3];
	
	$dst_ip = $dst_ip_array[0] << 24;
	$dst_ip |= ($dst_ip_array[1] << 16);
	$dst_ip |= ($dst_ip_array[2] << 8);
	$dst_ip |= $dst_ip_array[3];
	
	$mask = $mask_array[0] << 24;
	$mask |= ($mask_array[1] << 16);
	$mask |= ($mask_array[2] << 8);
	$mask |= $mask_array[3];
	
	$src_ip &= $mask;
	$dst_ip &= $mask;
	
	if( $src_ip == $dst_ip){
		$ret = 1;
	}else{
		$ret = 0;
	}
	return($ret);
}
?>
