<?php

define( 'TS_ANALYZE_FILE',				CONF_DIR . "/tsanalyze.ini" );
define( 'TS_PID_FILE',					CONF_DIR . "/pid.ini" );

define( 'PID_BASE_PMT_OUT',				0x100 );
define( 'PID_BASE_PCR_OUT',				0x110 );
define( 'PID_BASE_VIDEO_OUT',			0x120 );
define( 'PID_BASE_AUDIO_OUT',			0x130 );

define( 'TRANSCODE_BITRATE_LSB',		1000 );
define( 'TRANSCODE_BITRATE_MIN',		1 );
define( 'TRANSCODE_BITRATE_MAX',		50000 );

define( 'MUX_BITRATE_MIN',				1 );
define( 'MUX_BITRATE_MAX',				1000000 );


define('TRANSCODER_TOTAL_BITRATE_MIN',	0);
define('TRANSCODER_TOTAL_BITRATE_MAX',	100000000);

define('TUNER_BITRATE_MIN',				0);
define('TUNER_BITRATE_MAX',				100000000);

define('TRANSCODER_IN_BITRATE_MIN',		0);
define('TRANSCODER_IN_BITRATE_MAX',		100000000);

define('TRANSCODER_OUT_BITRATE_MIN',	0);
define('TRANSCODER_OUT_BITRATE_MAX',	100000000);

require_once( get_common_lang_file() );
require_once( get_lang_file(__FILE__) );	// Languageファイル読み込み

function save_conf_transcoder( &$old_config, $new_config, $filename ){
	// 入力チェック
	$on = 0;
	for( $i = 0 ; $i < $old_config['base']['TranscoderNum'] ; $i++ ){
		if( '1' == $new_config['status'.$i] ){
			$on = 1;
		}
		$old_config['transcoder'.$i]['Status'] = $new_config['status'.$i];
		
		if( isset( $new_config['proguram'.$i] ) ){
			$old_config['transcoder'.$i]['Program'] = $new_config['proguram'.$i];
		}
	}
	
	$old_config['base']['Status'] = $on;
	
	return save_ini_file_setup_save( $filename, $old_config );
}

/* PID Filter用のINIファイルの生成 */
function save_conf_mux_pid( $old_config, $new_config ){
	$out = array();
	
	// TS解析結果ファイルの読み込み
	if( is_file( TS_ANALYZE_FILE ) ){
		$ts_analyze = parse_ini_file( TS_ANALYZE_FILE, true );
	}else{
		return;
	}
	
	for( $i = 0 ; $i < $old_config['base']['TranscoderNum'] ; $i++ ){
		$mux_program = 0;
		
		if( isset( $new_config['proguram'.$i] ) ){
			// 新しい設定にProgoram番号が設定されている場合
			$mux_program = $new_config['proguram'.$i];
		}else if( isset( $old_config['transcoder0'.$i]['Program'] ) ){
			// 古い設定を使用
			$mux_program = $old_config['transcoder0'.$i]['Program'];
		}
		
		// プログラムの設定無し
		$out['PMT'.$i]['Enable']		 = 1;
		$out['PMT'.$i]['EnablePidOut']	 = 0;		// PMTだけはMUXからの出力をOFF固定
		$out['PMT'.$i]['PidIn']			 = 0;
		$out['PMT'.$i]['PidOut']		 = sprintf( '%04x', PID_BASE_PMT_OUT + $i );
		
		$out['PCR'.$i]['Enable']		 = 1;
		$out['PCR'.$i]['EnablePidOut']	 = 1;
		$out['PCR'.$i]['PidIn']			 = 0;
		$out['PCR'.$i]['PidOut']		 = sprintf( '%04x', PID_BASE_PCR_OUT + $i );
		
		$out['VIDEO'.$i]['Enable']		 = 1;
		$out['VIDEO'.$i]['EnablePidOut'] = 1;
		$out['VIDEO'.$i]['PidIn']		 = 0;
		$out['VIDEO'.$i]['PidOut']		 = sprintf( '%04x', PID_BASE_VIDEO_OUT + $i );
		
		$out['AUDIO'.$i]['Enable']		 = 1;
		$out['AUDIO'.$i]['EnablePidOut'] = 1;
		$out['AUDIO'.$i]['PidIn']		 = 0;
		$out['AUDIO'.$i]['PidOut']		 = sprintf( '%04x', PID_BASE_AUDIO_OUT + $i );
		
		if( isset( $ts_analyze['tuner'.$i]['ProgramNum'] ) ){
			for( $j = 0 ; $j < $ts_analyze['tuner'.$i]['ProgramNum'] ; $j++ ){
				if( $mux_program == $ts_analyze['tuner'.$i]['PmtProgramNumber_'.$j] ){
					for( $k = 0 ; isset( $ts_analyze['tuner'.$i]['StreamPid_'.$j.'_'.$k] ) ; $k++ ){
						$out['PMT'.$i]['PidIn']		 = $ts_analyze['tuner'.$i]['PmtPid_'.$j];
						$out['PCR'.$i]['PidIn']		 = $ts_analyze['tuner'.$i]['PmtPcrPid_'.$j];
						if( 0x02 == hexdec( $ts_analyze['tuner'.$i]['StreamType_' . $j.'_'.$k] ) ){
							$out['VIDEO'.$i]['PidIn']	 = $ts_analyze['tuner'.$i]['StreamPid_'.$j.'_'.$k];
						}else if( 0x03 == hexdec( $ts_analyze['tuner'.$i]['StreamType_'.$j.'_'.$k] ) ){
							$out['AUDIO'.$i]['PidIn']	 = $ts_analyze['tuner'.$i]['StreamPid_'.$j.'_'.$k];
						}
						
						if( $out['PCR'.$i]['PidIn'] == $out['VIDEO'.$i]['PidIn'] ){		// VideoにPCRを含める場合は出力PIDを同じにする
							$out['PCR'.$i]['PidOut'] = $out['VIDEO'.$i]['PidOut'];
						}
					}
					break;
				}
			}
		}
	}
	
	save_ini_file( TS_PID_FILE, $out, false );
}

function save_conf_transcoder_bitrate( &$old_config, $new_config, $filename ){
	global $lng;
	
	// 入力チェック
	for( $i = 0 ; $i < $old_config['base']['TranscoderNum'] ; $i++ ){
		if( !check_number($new_config['transcode_out_rate'.$i]) ||
			(TRANSCODE_BITRATE_MIN > $new_config['transcode_out_rate'.$i]) ||
			(TRANSCODE_BITRATE_MAX < $new_config['transcode_out_rate'.$i])	){
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_BIT_RATE'] );
		}
	}
	
	for( $i = 0 ; $i < $old_config['base']['TranscoderNum'] ; $i++ ){
		$old_config['transcoder'.$i]['TranscodeOutRate'] = $new_config['transcode_out_rate'.$i] * TRANSCODE_BITRATE_LSB;
	}
	
	return save_ini_file_setup_save( $filename, $old_config );
}

function save_conf_transcoder_mux( &$old_config, $new_config, $filename ){
	global $lng;
	
	// 入力チェック
	if( !check_number($new_config['mux_rate']) ||
		(MUX_BITRATE_MIN > $new_config['mux_rate']) ||
		(MUX_BITRATE_MAX < $new_config['mux_rate'])	){
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_BIT_RATE'] );
	}
	
	$old_config['base']['MuxRate'] = $new_config['mux_rate'] * TRANSCODE_BITRATE_LSB;
	$old_config['base']['Mode'] = $new_config['mode'] * TRANSCODE_BITRATE_LSB;
	
	return save_ini_file_setup_save( $filename, $old_config );
}

function save_conf_transcoder_pid( $num, &$old_config, $new_config, $filename ){
	global $lng;
	global $clng;
	
	// 入力チェック
	for( $i = 0 ; $i < $num ; $i++ ){
		if( !check_number_hex($new_config['pmt'.$i.'_pid_in'], 4 ) ||
			!check_number_hex($new_config['pcr'.$i.'_pid_in'], 4 ) ||
			!check_number_hex($new_config['video'.$i.'_pid_in'], 4 ) ||
			!check_number_hex($new_config['audio'.$i.'_pid_in'], 4 ) ||
			!check_number_hex($new_config['pmt'.$i.'_pid_out'], 4 ) ||
			!check_number_hex($new_config['pcr'.$i.'_pid_out'], 4 ) ||
			!check_number_hex($new_config['video'.$i.'_pid_out'], 4 ) ||
			!check_number_hex($new_config['audio'.$i.'_pid_out'], 4 ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => $lng['ER_PID'] );
		}
	}
	
	for( $i = 0 ; $i < $num ; $i++ ){
		$old_config['PMT'.$i]['Enable']			= $new_config['pmt'.$i.'_enable'];
		$old_config['PMT'.$i]['EnablePidOut']	= $new_config['pmt'.$i.'_enable_pid_out'];
		$old_config['PMT'.$i]['PidIn']			= $new_config['pmt'.$i.'_pid_in'];
		$old_config['PMT'.$i]['PidOut']			= $new_config['pmt'.$i.'_pid_out'];
		
		$old_config['PCR'.$i]['Enable']			= $new_config['pcr'.$i.'_enable'];
		$old_config['PCR'.$i]['EnablePidOut']	= $new_config['pcr'.$i.'_enable_pid_out'];
		$old_config['PCR'.$i]['PidIn']			= $new_config['pcr'.$i.'_pid_in'];
		$old_config['PCR'.$i]['PidOut']			= $new_config['pcr'.$i.'_pid_out'];
		
		$old_config['VIDEO'.$i]['Enable']		= $new_config['video'.$i.'_enable'];
		$old_config['VIDEO'.$i]['EnablePidOut']	= $new_config['video'.$i.'_enable_pid_out'];
		$old_config['VIDEO'.$i]['PidIn']		= $new_config['video'.$i.'_pid_in'];
		$old_config['VIDEO'.$i]['PidOut']		= $new_config['video'.$i.'_pid_out'];
		
		$old_config['AUDIO'.$i]['Enable']		= $new_config['audio'.$i.'_enable'];
		$old_config['AUDIO'.$i]['EnablePidOut']	= $new_config['audio'.$i.'_enable_pid_out'];
		$old_config['AUDIO'.$i]['PidIn']		= $new_config['audio'.$i.'_pid_in'];
		$old_config['AUDIO'.$i]['PidOut']		= $new_config['audio'.$i.'_pid_out'];
	}
	
	return array('RESULT'  => save_ini_file( TS_PID_FILE, $old_config, true ),
						 'MESSAGE' => $clng['ER_FILE_WRITE_OK'] );
}

// AGCゲインを算出する
// $agc_hex:0x1FFF => DVDD[V]
// $agc_hex:0x1000 => DVDD/2[V]
// $agc_hex:0x0000 => 0.00[V]
function calc_agc_gain( $agc ){
	return round( $agc * ( DVDD_VOLTAGE / 2 ) / 0x1000, 3 );
}

// ビットレート計算
function calc_transcoder_bitrate( $packet_num, $packet_size = 188 )
{
	return $packet_num * $packet_size * 8;
}

?>

