<?php

define('IP_PACKET_BUFFER_SIZE_MIN',    32);
define('IP_PACKET_BUFFER_SIZE_MAX',    1024);

require_once( get_common_lang_file() );
require_once( get_lang_file(__FILE__) );	// Languageファイル読み込み

// 
/**
 * VoIPの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_voip( &$old_config, $new_config, $filename ){
	global $lng;
	global $clng;
	
	// 入力情報のチェック
	if( false == check_ip( $new_config['setting_rx_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_IP_NG']);
	}
	if(!(preg_match("/^[0-9]+$/", $new_config['setting_port']))){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_PORT_NG']);
	}
	
// ★ 将来使用することがあればコメントアウトを外す
//	if( false == check_ip( $new_config['setting_tx_ip'] ) ){
//		return array('RESULT'  => false,
//					 'MESSAGE' => '送信IPアドレスの入力が不正です。');
//	}
	if( false == check_ip( $new_config['setting_multicast'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_MULTI_NG']);
	}
	if( false == check_multicast_ip( $new_config['setting_multicast'] ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_MULTI_RANGE_NG']);
	}
	if(!(preg_match("/^[0-9]+$/", $new_config['setting_ipbuffsize']))){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_BUFF_SIZE_NG']);
	}
	if( ( $new_config['setting_ipbuffsize']) < IP_PACKET_BUFFER_SIZE_MIN ||
		  IP_PACKET_BUFFER_SIZE_MAX < ($new_config['setting_ipbuffsize']) ){
		return array('RESULT'  => false,
					 'MESSAGE' => $lng['ER_BUFF_RANGE_NG']);
	}
	
	
	$old_config['VOIPRx']['Status']    = $new_config['status'];
//	$old_config['VOIPRx']['MAC']       = $new_config['setting_rx_mac'];
	$old_config['VOIPRx']['RxIP']      = $new_config['setting_rx_ip'];
	$old_config['VOIPRx']['Port']      = $new_config['setting_port'];
	$old_config['VOIPRx']['IPBuffSize']= $new_config['setting_ipbuffsize'];
// ★ 将来使用することがあればコメントアウトを外す
//	$old_config['VOIPRx']['TxIP']      = $new_config['setting_tx_ip'];	
	$old_config['VOIPRx']['EnableMultiCast'] = ( isset( $new_config['enable_multicast'] ) ) ? 1: 0;
	$old_config['VOIPRx']['MultiCast'] = $new_config['setting_multicast'];

	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => $clng['ER_FILE_WRITE_NG']);
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => $clng['ER_FILE_WRITE_OK']);
	}
}
?>
