<?php

define('FEC_DXL_MAX',		100);

// 
/**
 * VoIP Txの設定情報の保存
 * @param type $old_config		変更前INI情報
 * @param type $new_config		更新するINI情報（POSTデータ）
 * @param type $filename		INIファイル名
 * @return 連想配列				['RESULT']  実行結果
 *                              ['MESSAGE'] メッセージ
 */
function save_conf_voip_tx( &$old_config, $new_config, $filename ){
	// 入力情報のチェック
	if( false == check_ip( $new_config['setting_tx_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '送信IPアドレスの入力が不正です。');
	}
	if( false == check_netmask( $new_config['setting_netmask'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => "入力したネットマスクの値が不正です。ネットマスクは 0.0.0.0 ～ 255.255.255." . NETMASK_MAX . " の範囲で設定可能です。");
	}
	if( false == check_ip( $new_config['setting_rx_ip'], true ) ){
		return array('RESULT'  => false,
					 'MESSAGE' => '受信IPアドレスの入力が不正です。');
	}
	if(!(preg_match("/^[0-9]+$/", $new_config['setting_rx_port']))){
		return array('RESULT'  => false,
					 'MESSAGE' => '受信ポート番号には数値を設定してください。');
	}
	if($new_config['setting_fec_d_status'] == 0){
		$new_config['setting_fec_d'] = 0;
	}
	if(!(preg_match("/^[0-9]+$/", $new_config['setting_fec_d']))){
		return array('RESULT'  => false,
					 'MESSAGE' => 'FEC Dには数値を設定してください。');
	}
	if($new_config['setting_fec_l_status'] == 0){
		$new_config['setting_fec_l'] = 0;
	}
	if(!(preg_match("/^[0-9]+$/", $new_config['setting_fec_l']))){
		return array('RESULT'  => false,
					 'MESSAGE' => 'FEC Lには数値を設定してください。');
	}
	if( ($new_config['setting_fec_d_status'] == 1) &&
		($new_config['setting_fec_l_status'] == 1) ) {
		if( FEC_DXL_MAX < ( $new_config['setting_fec_d'] * $new_config['setting_fec_l'] ) ){
			return array('RESULT'  => false,
						 'MESSAGE' => 'FEC DとFEC Lは乗算して'.FEC_DXL_MAX.'以下となるように設定してください。');
		}
	}
	
	$old_config['VOIPTx']['Status']    = $new_config['status'];
	$old_config['VOIPTx']['TxIP']      = $new_config['setting_tx_ip'];
	$old_config['VOIPTx']['RxIP']      = $new_config['setting_rx_ip'];
	$old_config['VOIPTx']['RxPort']    = $new_config['setting_rx_port'];
	$old_config['VOIPTx']['NetMask']   = $new_config['setting_netmask'];
	$old_config['VOIPTx']['Gw']        = $new_config['setting_gw'];
	$old_config['VOIPTx']['FecD']      = $new_config['setting_fec_d'];
	$old_config['VOIPTx']['FecL']      = $new_config['setting_fec_l'];
	$old_config['VOIPTx']['PacketCnt'] = $new_config['setting_packet_cnt'];
	$old_config['VOIPTx']['PacketSize']= $new_config['setting_packet_size'];

	// ファイルへ保存
	if( false == save_ini_file( $filename['Setup'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}
	if( false == save_ini_file( $filename['Save'], $old_config ) ) {
		return array('RESULT'  => false,
					 'MESSAGE' => '設定ファイルへの書き込みに失敗しました。');
	}else{
		return array('RESULT'  => true,
					 'MESSAGE' => '設定が正常に終了しました。');
	}
}
?>
